import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface SensitiveFileConfig extends cdktf.TerraformMetaArguments {
    /**
    * Sensitive content to store in the file, expected to be an UTF-8 encoded string.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/local/r/sensitive_file#content SensitiveFile#content}
    */
    readonly content?: string;
    /**
    * Sensitive content to store in the file, expected to be binary encoded as base64 string.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/local/r/sensitive_file#content_base64 SensitiveFile#content_base64}
    */
    readonly contentBase64?: string;
    /**
    * Permissions to set for directories created (in numeric notation).
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/local/r/sensitive_file#directory_permission SensitiveFile#directory_permission}
    */
    readonly directoryPermission?: string;
    /**
    * Permissions to set for the output file (in numeric notation).
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/local/r/sensitive_file#file_permission SensitiveFile#file_permission}
    */
    readonly filePermission?: string;
    /**
    *
                      The path to the file that will be created.
                      Missing parent directories will be created.
                      If the file already exists, it will be overridden with the given content.
                  
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/local/r/sensitive_file#filename SensitiveFile#filename}
    */
    readonly filename: string;
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/local/r/sensitive_file#id SensitiveFile#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * Path to file to use as source for the one we are creating.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/local/r/sensitive_file#source SensitiveFile#source}
    */
    readonly source?: string;
}
/**
* Represents a {@link https://www.terraform.io/docs/providers/local/r/sensitive_file local_sensitive_file}
*/
export declare class SensitiveFile extends cdktf.TerraformResource {
    static readonly tfResourceType = "local_sensitive_file";
    /**
    * Create a new {@link https://www.terraform.io/docs/providers/local/r/sensitive_file local_sensitive_file} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options SensitiveFileConfig
    */
    constructor(scope: Construct, id: string, config: SensitiveFileConfig);
    private _content?;
    get content(): string;
    set content(value: string);
    resetContent(): void;
    get contentInput(): string | undefined;
    private _contentBase64?;
    get contentBase64(): string;
    set contentBase64(value: string);
    resetContentBase64(): void;
    get contentBase64Input(): string | undefined;
    private _directoryPermission?;
    get directoryPermission(): string;
    set directoryPermission(value: string);
    resetDirectoryPermission(): void;
    get directoryPermissionInput(): string | undefined;
    private _filePermission?;
    get filePermission(): string;
    set filePermission(value: string);
    resetFilePermission(): void;
    get filePermissionInput(): string | undefined;
    private _filename?;
    get filename(): string;
    set filename(value: string);
    get filenameInput(): string | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _source?;
    get source(): string;
    set source(value: string);
    resetSource(): void;
    get sourceInput(): string | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
//# sourceMappingURL=sensitive-file.d.ts.map